@@ -1,3 +1,7 @@
+from .api_gateway_authorizer import (
+    APIGatewayRequestAuthorizerEvent,
+    APIGatewayTokenAuthorizerEvent,
+)
 from .api_gateway_proxy import APIGatewayProxyEventV1, APIGatewayProxyEventV2
 from .cloud_watch_events import CloudWatchEventsMessageEvent
 from .cloud_watch_logs import CloudWatchLogsEvent
